/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: ssc-sensor-suid.proto */

#ifndef PROTOBUF_C_ssc_2dsensor_2dsuid_2eproto__INCLUDED
#define PROTOBUF_C_ssc_2dsensor_2dsuid_2eproto__INCLUDED

#include <protobuf-c/protobuf-c.h>

PROTOBUF_C__BEGIN_DECLS

#if PROTOBUF_C_VERSION_NUMBER < 1003000
# error This file was generated by a newer version of protobuf-c which is incompatible with your libprotobuf-c headers. Please update your headers.
#elif 1005002 < PROTOBUF_C_MIN_COMPILER_VERSION
# error This file was generated by an older version of protobuf-c which is incompatible with your libprotobuf-c headers. Please regenerate this file with a newer version of protobuf-c.
#endif

#include "ssc-common.pb-c.h"

typedef struct SscSuidRequest SscSuidRequest;
typedef struct SscSuidResponse SscSuidResponse;


/* --- enums --- */


/* --- messages --- */

/*
 * 
 * SUID Sensor specific request data.
 * @data_type: retrieve all sensors exposing the specified data type.
 * An empty value will return all sensors.
 * @enable_updates: setting this to true will enable updates 
 * for the specified data_type.
 * @only_default_values: setting this to true will only return 
 * the default sensor for the data_type, even if multiple sensors expose it.
 */
struct  SscSuidRequest
{
  ProtobufCMessage base;
  char *data_type;
  protobuf_c_boolean has_enable_updates;
  protobuf_c_boolean enable_updates;
  protobuf_c_boolean has_only_default_values;
  protobuf_c_boolean only_default_values;
};
#define SSC_SUID_REQUEST__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&ssc_suid_request__descriptor) \
, NULL, 0, 0, 0, 0 }


/*
 * SUID Sensor specific response data.
 * @data_type: the data_type for which the list of UIDs match.
 * @uid: list of matching UIDs.
 */
struct  SscSuidResponse
{
  ProtobufCMessage base;
  char *data_type;
  size_t n_uid;
  SscUid **uid;
};
#define SSC_SUID_RESPONSE__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&ssc_suid_response__descriptor) \
, NULL, 0,NULL }


/* SscSuidRequest methods */
void   ssc_suid_request__init
                     (SscSuidRequest         *message);
size_t ssc_suid_request__get_packed_size
                     (const SscSuidRequest   *message);
size_t ssc_suid_request__pack
                     (const SscSuidRequest   *message,
                      uint8_t             *out);
size_t ssc_suid_request__pack_to_buffer
                     (const SscSuidRequest   *message,
                      ProtobufCBuffer     *buffer);
SscSuidRequest *
       ssc_suid_request__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   ssc_suid_request__free_unpacked
                     (SscSuidRequest *message,
                      ProtobufCAllocator *allocator);
/* SscSuidResponse methods */
void   ssc_suid_response__init
                     (SscSuidResponse         *message);
size_t ssc_suid_response__get_packed_size
                     (const SscSuidResponse   *message);
size_t ssc_suid_response__pack
                     (const SscSuidResponse   *message,
                      uint8_t             *out);
size_t ssc_suid_response__pack_to_buffer
                     (const SscSuidResponse   *message,
                      ProtobufCBuffer     *buffer);
SscSuidResponse *
       ssc_suid_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   ssc_suid_response__free_unpacked
                     (SscSuidResponse *message,
                      ProtobufCAllocator *allocator);
/* --- per-message closures --- */

typedef void (*SscSuidRequest_Closure)
                 (const SscSuidRequest *message,
                  void *closure_data);
typedef void (*SscSuidResponse_Closure)
                 (const SscSuidResponse *message,
                  void *closure_data);

/* --- services --- */


/* --- descriptors --- */

extern const ProtobufCMessageDescriptor ssc_suid_request__descriptor;
extern const ProtobufCMessageDescriptor ssc_suid_response__descriptor;

PROTOBUF_C__END_DECLS


#endif  /* PROTOBUF_C_ssc_2dsensor_2dsuid_2eproto__INCLUDED */
