/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: ssc-sensor-magnetometer.proto */

#ifndef PROTOBUF_C_ssc_2dsensor_2dmagnetometer_2eproto__INCLUDED
#define PROTOBUF_C_ssc_2dsensor_2dmagnetometer_2eproto__INCLUDED

#include <protobuf-c/protobuf-c.h>

PROTOBUF_C__BEGIN_DECLS

#if PROTOBUF_C_VERSION_NUMBER < 1003000
# error This file was generated by a newer version of protobuf-c which is incompatible with your libprotobuf-c headers. Please update your headers.
#elif 1005002 < PROTOBUF_C_MIN_COMPILER_VERSION
# error This file was generated by an older version of protobuf-c which is incompatible with your libprotobuf-c headers. Please regenerate this file with a newer version of protobuf-c.
#endif


typedef struct SscMagnetometerResponse SscMagnetometerResponse;


/* --- enums --- */


/* --- messages --- */

/*
 * Magnetometer Sensor specific response data.
 * @magnetic_field: magnetic field per axis in µT: X-axis [0], Y-axis [1], Z-axis [2].
 * @accuracy: how reliable the value is [0, 3]. Higher is more accurate, 0 is unreliable.
 */
struct  SscMagnetometerResponse
{
  ProtobufCMessage base;
  size_t n_magnetic_field;
  float *magnetic_field;
  int32_t accuracy;
};
#define SSC_MAGNETOMETER_RESPONSE__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&ssc_magnetometer_response__descriptor) \
, 0,NULL, 0 }


/* SscMagnetometerResponse methods */
void   ssc_magnetometer_response__init
                     (SscMagnetometerResponse         *message);
size_t ssc_magnetometer_response__get_packed_size
                     (const SscMagnetometerResponse   *message);
size_t ssc_magnetometer_response__pack
                     (const SscMagnetometerResponse   *message,
                      uint8_t             *out);
size_t ssc_magnetometer_response__pack_to_buffer
                     (const SscMagnetometerResponse   *message,
                      ProtobufCBuffer     *buffer);
SscMagnetometerResponse *
       ssc_magnetometer_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   ssc_magnetometer_response__free_unpacked
                     (SscMagnetometerResponse *message,
                      ProtobufCAllocator *allocator);
/* --- per-message closures --- */

typedef void (*SscMagnetometerResponse_Closure)
                 (const SscMagnetometerResponse *message,
                  void *closure_data);

/* --- services --- */


/* --- descriptors --- */

extern const ProtobufCMessageDescriptor ssc_magnetometer_response__descriptor;

PROTOBUF_C__END_DECLS


#endif  /* PROTOBUF_C_ssc_2dsensor_2dmagnetometer_2eproto__INCLUDED */
